@@ -463,11 +463,13 @@ Lnk reduce(Worker* mem, u64 root, u64 slen) {
         }
         case DP0:
         case DP1: {
+          #ifdef PARALLEL
           // TODO: reason about this, comment
           atomic_flag* flag = ((atomic_flag*)(mem->node + get_loc(term,0))) + 6;
           if (atomic_flag_test_and_set(flag) != 0) {
             continue;
           }
+          #endif
           stk_push(&stack, host);
           host = get_loc(term, 2);
           continue;
@@ -676,9 +678,10 @@ Lnk reduce(Worker* mem, u64 root, u64 slen) {
             }
 
           }
-
+          #ifdef PARALLEL
           atomic_flag* flag = ((atomic_flag*)(mem->node + get_loc(term,0))) + 6;
           atomic_flag_clear(flag);
+          #endif
           break;
         }
         case OP2: {
